==> kubernetes-model-admissionregistration-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/authentication/TokenReviewStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.authentication;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class TokenReviewStatusBuilder extends io.fabric8.kubernetes.api.model.authentication.TokenReviewStatusFluentImpl<io.fabric8.kubernetes.api.model.authentication.TokenReviewStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.authentication.TokenReviewStatus,io.fabric8.kubernetes.api.model.authentication.TokenReviewStatusBuilder>{
  public TokenReviewStatusBuilder() {
    this(false);
  }
  public TokenReviewStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new TokenReviewStatus(), validationEnabled);
  }
  public TokenReviewStatusBuilder(io.fabric8.kubernetes.api.model.authentication.TokenReviewStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public TokenReviewStatusBuilder(io.fabric8.kubernetes.api.model.authentication.TokenReviewStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new TokenReviewStatus(), validationEnabled);
  }
  public TokenReviewStatusBuilder(io.fabric8.kubernetes.api.model.authentication.TokenReviewStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.authentication.TokenReviewStatus instance) {
    this(fluent, instance, false);
  }
  public TokenReviewStatusBuilder(io.fabric8.kubernetes.api.model.authentication.TokenReviewStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.authentication.TokenReviewStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAudiences(instance.getAudiences()); 
    fluent.withAuthenticated(instance.getAuthenticated()); 
    fluent.withError(instance.getError()); 
    fluent.withUser(instance.getUser()); 
    this.validationEnabled = validationEnabled; 
  }
  public TokenReviewStatusBuilder(io.fabric8.kubernetes.api.model.authentication.TokenReviewStatus instance) {
    this(instance,false);
  }
  public TokenReviewStatusBuilder(io.fabric8.kubernetes.api.model.authentication.TokenReviewStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAudiences(instance.getAudiences()); 
    this.withAuthenticated(instance.getAuthenticated()); 
    this.withError(instance.getError()); 
    this.withUser(instance.getUser()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.authentication.TokenReviewStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.authentication.TokenReviewStatus build() {
    TokenReviewStatus buildable = new TokenReviewStatus(fluent.getAudiences(),fluent.getAuthenticated(),fluent.getError(),fluent.getUser());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TokenReviewStatusBuilder that = (TokenReviewStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-admissionregistration-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/authentication/TokenReviewStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.authentication;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class TokenReviewStatusBuilder extends io.fabric8.kubernetes.api.model.authentication.TokenReviewStatusFluentImpl<io.fabric8.kubernetes.api.model.authentication.TokenReviewStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.authentication.TokenReviewStatus,io.fabric8.kubernetes.api.model.authentication.TokenReviewStatusBuilder>{
  public TokenReviewStatusBuilder() {
    this(false);
  }
  public TokenReviewStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new TokenReviewStatus(), validationEnabled);
  }
  public TokenReviewStatusBuilder(io.fabric8.kubernetes.api.model.authentication.TokenReviewStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public TokenReviewStatusBuilder(io.fabric8.kubernetes.api.model.authentication.TokenReviewStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new TokenReviewStatus(), validationEnabled);
  }
  public TokenReviewStatusBuilder(io.fabric8.kubernetes.api.model.authentication.TokenReviewStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.authentication.TokenReviewStatus instance) {
    this(fluent, instance, false);
  }
  public TokenReviewStatusBuilder(io.fabric8.kubernetes.api.model.authentication.TokenReviewStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.authentication.TokenReviewStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAudiences(instance.getAudiences()); 
    fluent.withAuthenticated(instance.getAuthenticated()); 
    fluent.withError(instance.getError()); 
    fluent.withUser(instance.getUser()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public TokenReviewStatusBuilder(io.fabric8.kubernetes.api.model.authentication.TokenReviewStatus instance) {
    this(instance,false);
  }
  public TokenReviewStatusBuilder(io.fabric8.kubernetes.api.model.authentication.TokenReviewStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAudiences(instance.getAudiences()); 
    this.withAuthenticated(instance.getAuthenticated()); 
    this.withError(instance.getError()); 
    this.withUser(instance.getUser()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.authentication.TokenReviewStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.authentication.TokenReviewStatus build() {
    TokenReviewStatus buildable = new TokenReviewStatus(fluent.getAudiences(),fluent.getAuthenticated(),fluent.getError(),fluent.getUser());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TokenReviewStatusBuilder that = (TokenReviewStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
